==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/FinancialEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialCalculationDataSourceDescriptionMetadata } from "./FinancialCalculationDataSourceDescriptionMetadata";
import { FinancialCalculationSupportingCalculationsDescriptionMetadata } from "./FinancialCalculationSupportingCalculationsDescriptionMetadata";
import { FinancialEventArgsDescription } from "./FinancialEventArgsDescription";
/**
 * @hidden
 */
export let FinancialEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialEventArgsDescriptionMetadata.a == null) {
                FinancialEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialEventArgsDescriptionMetadata.c(FinancialEventArgsDescriptionMetadata.a);
            }
            if (a.j(FinancialEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(FinancialEventArgsDescriptionMetadata.a);
            FinancialCalculationDataSourceDescriptionMetadata.d(a);
            FinancialCalculationSupportingCalculationsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Position", "Number:int");
            a.item("Count", "Number:int");
            a.item("DataSource", "ExportedType:FinancialCalculationDataSource");
            a.item("SupportingCalculations", "ExportedType:FinancialCalculationSupportingCalculations");
        }
        static d(a) {
            FinancialEventArgsDescriptionMetadata.b(a);
            a.aa("FinancialEventArgs", () => new FinancialEventArgsDescription());
            a.z("FinancialEventArgs", FinancialEventArgsDescriptionMetadata.a);
        }
    }
    FinancialEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialEventArgsDescriptionMetadata, 'FinancialEventArgsDescriptionMetadata');
    FinancialEventArgsDescriptionMetadata.a = null;
    return FinancialEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FinancialEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialCalculationDataSourceDescriptionMetadata } from "./FinancialCalculationDataSourceDescriptionMetadata";
import { FinancialCalculationSupportingCalculationsDescriptionMetadata } from "./FinancialCalculationSupportingCalculationsDescriptionMetadata";
import { FinancialEventArgsDescription } from "./FinancialEventArgsDescription";
/**
 * @hidden
 */
export let FinancialEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialEventArgsDescriptionMetadata.a == null) {
                FinancialEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialEventArgsDescriptionMetadata.c(FinancialEventArgsDescriptionMetadata.a);
            }
            if (a.k(FinancialEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(FinancialEventArgsDescriptionMetadata.a);
            FinancialCalculationDataSourceDescriptionMetadata.d(a);
            FinancialCalculationSupportingCalculationsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Position", "Number:int");
            a.item("Count", "Number:int");
            a.item("DataSource", "ExportedType:FinancialCalculationDataSource");
            a.item("SupportingCalculations", "ExportedType:FinancialCalculationSupportingCalculations");
        }
        static d(a) {
            FinancialEventArgsDescriptionMetadata.b(a);
            a.ac("FinancialEventArgs", () => new FinancialEventArgsDescription());
            a.ab("FinancialEventArgs", FinancialEventArgsDescriptionMetadata.a);
        }
    }
    FinancialEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialEventArgsDescriptionMetadata, 'FinancialEventArgsDescriptionMetadata');
    FinancialEventArgsDescriptionMetadata.a = null;
    return FinancialEventArgsDescriptionMetadata;
})();
